@@ -337,6 +337,7 @@ GSM_PhoneModel allmodels[] = {
 	{"6126" ,"RM-124","Nokia 6126", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6131" ,"RM-115","Nokia 6131", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6131 NFC" ,"RM-216","Nokia 6131 NFC", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
+	{"6133" ,"RM-126","Nokia 6133", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6151" ,"RM-200","Nokia 6151", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,0}},/* fixme */
 	{"6170" ,"RM-47" ,"Nokia 6170", {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},
 	{"6170" ,"RM-48" ,"Nokia 6170", {F_PBKTONEGAL,F_TODO66,F_PBKSMSLIST,F_PBKUSER,F_WAPMMSPROXY,F_NOTES,F_CHAT,F_SYNCML,F_FILES2,0}},
@@ -398,6 +399,8 @@ GSM_PhoneModel allmodels[] = {
 	{"8910" ,"NHM-4" ,"Nokia 8910", {F_CAL62,F_NOMIDI,F_NOFILESYSTEM,F_NOMMS,0}},
 	{"8910i","NHM-4" ,"Nokia 8910i",{F_CAL62,F_NOMIDI,F_NOFILESYSTEM,F_NOMMS,0}},
 	{"C2-01","RM-721","Nokia C2-01", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_6230iCALLER,0}},/* fixme */
+	{"306","RM-767","Nokia Asha 306", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_6230iCALLER,0}},/* fixme */
+	{"112","RM-837","Nokia 112", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_6230iCALLER,0}},/* fixme */
 	{"C3"	,"RM-614","Nokia C3", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_6230iCALLER,0}},/* fixme */
 	{"X2-00","RM-618","Nokia X2-00", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_6230iCALLER,0}},/* guess */
 	{"X3"	,"RM-540","Nokia X3", {F_SERIES40_30,F_FILES2,F_TODO66,F_RADIO,F_NOTES,F_SMS_FILES,F_6230iCALLER,0}},/* fixme */
@@ -449,6 +452,7 @@ GSM_PhoneModel allmodels[] = {
 	{"ME45" ,	  "3618" ,	  "",				   {0}},
 	{"S55" ,	  "S55" ,	  "",				   {0}},
 	{"S65" ,	  "S65" ,	  "SIEMENS S65",		   {F_SIEMENS_PBK, 0}},
+	{"C72" ,	  "C72" ,	  "SIEMENS C72",		   {F_SIEMENS_PBK, 0}},
 	{"S68",		  "S68",	  "",				   {F_OBEX,F_SQWE, 0}},
 	{"MC75" ,	  "MC75",	  "",				   {F_NO_ATOBEX, 0}},
 	{"AX75",	  "AX75",	  "SIEMENS AX75",		   {F_SIEMENS_PBK, 0}},
@@ -471,6 +475,7 @@ GSM_PhoneModel allmodels[] = {
 	{"D980",	  "SAMSUNG SGH-D980" , "",			   {F_NO_ATOBEX, 0}},
 	{"B2100",         "SAMSUNG B2100", "",				   {F_DISABLE_CMGL, F_SMS_SM, F_SMS_ME, F_SMS_UTF8_ENCODED, F_READ_SMSTEXTMODE, F_FORCE_UTF8, F_NO_UTF8, F_SAMSUNG_UTF8, F_TSSPCSW, F_OBEX, F_IRMC_LEVEL_2, 0}},
 	{"GT-E2370",      "SAMSUNG GT-E2370", "",			   {F_DISABLE_CMGL, F_SMS_SM, F_SMS_ME, F_SMS_UTF8_ENCODED, F_READ_SMSTEXTMODE, F_FORCE_UTF8, F_NO_UTF8, F_SAMSUNG_UTF8, F_TSSPCSW, F_OBEX, F_IRMC_LEVEL_2, 0}},
+	{"GT-B2710",      "SAMSUNG GT-B2710", "",			   {F_DISABLE_CMGL, F_SMS_SM, F_SMS_ME, F_SMS_UTF8_ENCODED, F_READ_SMSTEXTMODE, F_FORCE_UTF8, F_NO_UTF8, F_SAMSUNG_UTF8, F_TSSPCSW, F_OBEX, F_IRMC_LEVEL_2, 0}},
 
 	/* Philips */
 	{"Xenium 9@9d",	  "Xenium 9@9d", "",				   {F_OBEX, 0}},
