@@ -1115,7 +1115,7 @@ GSM_Error GSM_DispatchMessage(GSM_StateMachine *s)
 	}
 
 	if (disp) {
-		smprintf(s,". If you can, please report it (see <http://wammu.eu/support/bugs/>). Thank you\n");
+		smprintf(s,". Please report the error, see <http://wammu.eu/support/bugs/>. Thank you\n");
 		if (Phone->SentMsg != NULL) {
 			smprintf(s,"LAST SENT frame ");
 			smprintf(s, "type 0x%02X/length %ld", Phone->SentMsg->Type, (long)Phone->SentMsg->Length);
@@ -1287,7 +1287,7 @@ GSM_Error GSM_ReadConfig(INI_Section *cfg_info, GSM_Config *cfg, int num)
 #if defined(WIN32) || defined(DJGPP)
         static const char *DefaultPort		= "com2:";
 #else
-        static const char *DefaultPort		= "/dev/ttyACM0";
+        static const char *DefaultPort		= "/dev/ttyUSB0";
 #endif
         static const char *DefaultModel		= "";
         static const char *DefaultConnection		= "at";
