@@ -1777,7 +1777,8 @@ GSM_Phone_Functions N7110Phone = {
 	NOTSUPPORTED,			/* 	DeleteFolder		*/
 	NOTSUPPORTED,			/* 	GetGPRSAccessPoint	*/
 	NOTSUPPORTED,			/* 	SetGPRSAccessPoint	*/
-	NOTSUPPORTED			/* 	GetScreenshot		*/
+	NOTSUPPORTED,			/* 	GetScreenshot		*/
+	NOTSUPPORTED			/* 	SetPower		*/
 };
 
 #endif
