@@ -11,6 +11,7 @@
 
 #define _XOPEN_SOURCE
 #define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 #include <time.h>
 #include <gammu.h>
 #include "../../helper/strptime.h"
@@ -249,6 +250,9 @@ void SMSDSQL_Time2String(GSM_SMSDConfig * Config, time_t timestamp, char *static
 	} else if (strcasecmp(driver_name, "access") == 0) {
 		timestruct = gmtime(&timestamp);
 		strftime(static_buff, size, "'%Y-%m-%d %H:%M:%S'", timestruct);
+	} else if (strcasecmp(driver_name, "mysql") == 0 || strcasecmp(driver_name, "native_mysql") == 0) {
+		timestruct = localtime(&timestamp);
+		strftime(static_buff, size, "%Y-%m-%d %H:%M:%S", timestruct);
 	} else if (strcasecmp(Config->driver, "odbc") == 0) {
 		timestruct = gmtime(&timestamp);
 		strftime(static_buff, size, "{ ts '%Y-%m-%d %H:%M:%S' }", timestruct);
@@ -269,6 +273,20 @@ static SQL_Error SMSDSQL_NamedQuery(GSM_SMSDConfig * Config, const char *sql_que
 	int n, argc = 0;
 	struct GSM_SMSDdbobj *db = Config->db;
 
+	GSM_NetworkInfo NetInfo;
+	char empty[1] = "";
+	char *NetCode, *NetName;
+
+	NetCode = empty;
+	NetName = empty;
+
+	if ( GSM_GetNetworkInfo(Config->gsm, &NetInfo) == ERR_NONE) {
+		NetCode = NetInfo.NetworkCode;
+		if (NetInfo.NetworkName[0] != 0x00 || NetInfo.NetworkName[1] != 0x00) {
+			NetName = DecodeUnicodeConsole(NetInfo.NetworkName);
+		}
+	}
+
 	if (params != NULL) {
 		while (params[argc].type != SQL_TYPE_NONE) argc++;
 	}
@@ -315,6 +333,12 @@ static SQL_Error SMSDSQL_NamedQuery(GSM_SMSDConfig * Config, const char *sql_que
 			case 'P':
 				to_print = Config->PhoneID;
 				break;
+			case 'O':
+				to_print = NetCode;
+				break;
+			case 'M':
+				to_print = NetName;
+				break;
 			case 'N':
 				snprintf(static_buff, sizeof(static_buff), "Gammu %s, %s, %s", GAMMU_VERSION, GetOS(), GetCompiler());
 				to_print = static_buff;
@@ -1178,6 +1202,8 @@ GSM_Error SMSDSQL_ReadConfiguration(GSM_SMSDConfig *Config)
 		"INSERT INTO phones (",
 			ESCAPE_FIELD("IMEI"),
 			", ", ESCAPE_FIELD("ID"),
+			", ", ESCAPE_FIELD("NetCode"),
+			", ", ESCAPE_FIELD("NetName"),
 			", ", ESCAPE_FIELD("Send"),
 			", ", ESCAPE_FIELD("Receive"),
 			", ", ESCAPE_FIELD("InsertIntoDB"),
@@ -1185,7 +1211,7 @@ GSM_Error SMSDSQL_ReadConfiguration(GSM_SMSDConfig *Config)
 			", ", ESCAPE_FIELD("Client"),
 			", ", ESCAPE_FIELD("Battery"),
 			", ", ESCAPE_FIELD("Signal"),
-			") VALUES (%I, %P, %1, %2, ",
+			") VALUES (%I, %P, %O, %M, %1, %2, ",
 			SMSDSQL_Now(Config),
 			", ",
 			SMSDSQL_NowPlus(Config, 10),
@@ -1385,6 +1411,8 @@ GSM_Error SMSDSQL_ReadConfiguration(GSM_SMSDConfig *Config)
 			ESCAPE_FIELD("TimeOut"), "= ", SMSDSQL_NowPlus(Config, 10),
 			", ", ESCAPE_FIELD("Battery"), " = %1"
 			", ", ESCAPE_FIELD("Signal"), " = %2"
+			", ", ESCAPE_FIELD("NetCode"), " = %O"
+			", ", ESCAPE_FIELD("NetName"), " = %M"
 			" WHERE ", ESCAPE_FIELD("IMEI"), " = %I", NULL) != ERR_NONE) {
 		return ERR_UNKNOWN;
 	}
